=================
sphinx-bioschemas
=================

A Sphinx extension to include `Bioschemas profiles <https://bioschemas.org/>`_ or any other `Schema.org structured metadata <https://schema.org>`_ in your content.

Further details at: https://biocorecrg.github.io/sphinx-bioschemas/
